==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MPH_problemheap.h <==
/* $Date: 1997/08/26 13:18:00 $  $Author: chh $  $Revision: 1.15 $ */

/**************************************************************************/
/* FILE:             MPH_problemheap.h 					  */
/* Autor:            Karsten Morisse                                      */
/* Erstellt:         02/01/92                                             */
/* Letzte Aenderung: 20/02/92                                             */
/**************************************************************************/

#ifndef __MPH_problemheap__
#define __MPH_problemheap__


/**************************************************************************/
/* Dieses File enthaelt die Deklarationen des Modules MPH_problemheap     */
/**************************************************************************/

/**************************************************************************/
/* In MPHTsave werden wichtige Werte f"ur ein Task gespeichert, die keine */
/* S-Zeiger sind.                                                         */
/**************************************************************************/
typedef struct
{
  long MUPV_REAL_PROC_DEPTH ;
  //chh_break:
  short abbruch;  // Muss die Task abgebrochen werden?
  unsigned long process;  // Prozess, der die Task bearbeitet - wird im Moment nicht benoetigt
  jmp_buf back;   // long_jmp-Ruecksprungadresse, wenn Task abgebrochen wird - wird im Moment nicht benoetigt
} MPHTsave ;



	/* Zeiger auf Problemheap					  */
	/* ACHTUNG: Wird nur im Fall 'PARALLEL' wirklich benoetigt.	  */
	/*          Aus Kompatibilitaetsgruenden wird sie jedoch in 	  */
	/*	    beiden Faellen deklariert.				  */

#define MPHC_HISTORY_SIZE_DEFAULT 30


extern S_Pointer	MPHV_START;	
extern S_Pointer	MPHV_RUN;   // chh_break: Runheap
extern jmp_buf          MPHV_JumpBreak; // chh_break: Sprungmarke fuer paralleles break



void MPH_delete_subtasks(S_Pointer parallel_env) ;


#ifdef PARALLEL

S_Pointer MPH_build_task(S_Pointer stmt, S_Pointer priv, S_Pointer cnt, S_Pointer res, S_Pointer ret, S_Pointer break_erlaubt);

void MPH_do_task(S_Pointer task, int set_break_erlaubt);
MUPbool MPH_get(VOID);
void MPH_get_sleep(VOID) ;
void MPH_init(VOID);
void MPH_exit(VOID);
void MPH_put(S_Pointer task);
void MPH_prepare_stack(S_Pointer priv, long flag);

//chh_break: Variable, die anzeigt, ob Auswertung wg. Break mit longjump verlassen wurde
GLOBAL_DECL(long, MPHV_BREAKED);

#else

S_Pointer MPH_get_random(long);
S_Pointer MPH_get_task(VOID);
S_Pointer MPH_build_task(S_Pointer stmt, S_Pointer priv, S_Pointer cnt, S_Pointer res, S_Pointer ret, S_Pointer break_erlaubt);
 
MUPbool MPH_get(long);
#define MPH_get_sleep() MPH_get(1L) 
void MPH_init(VOID);
void MPH_exit(VOID);
void MPH_put(S_Pointer task);
void MPH_prepare_stack(S_Pointer priv, long flag);
 
long MPH_count_problemheap(VOID);
 
#endif /* PARALLEL */

#ifdef DOS_FILENAMES
  #include "MUP_ext.h"
  #include "MPA_pars.h"
#else
  #include "MUP_extern.h"
  #include "MPA_parser.h"
#endif

// chh_break: Funktion, die abtestet, ob die aktuelle Task abgebrochen werden soll
//            Springt zurueck, wenn ja
inline void MPH_check_actual_task()
{
#ifdef PARALLEL
if ((GLOBAL_READ(MUPV_actual_task_element)) && !(GLOBAL_READ(MUPV_break_impossible)) )
  if ((MMMZ( MMMP(MMMP(&GLOBAL_READ(MUPV_actual_task_element),0L,MMMread), 7L, MMMread) , MPHTsave, MMMread))->abbruch)
  {
    GLOBAL_WRITE(MPHV_BREAKED,1);
    //chh_tmp
    //printf("Prozess %ld bricht Task ab und springt zurueck!\n",GLOBAL_READ(MMMVson));
    longjmp(MPHV_JumpBreak, 1) ;
  }
#endif
}

// chh_break: Funktion, die testet, ob Task als abzubrechen markiert ist.
inline int MPH_check_breaked()
{
#ifdef PARALLEL
if (GLOBAL_READ(MUPV_actual_task_element))
  return (MMMZ( MMMP(MMMP(&GLOBAL_READ(MUPV_actual_task_element),0L,MMMread), 7L, MMMread) , MPHTsave, MMMread))->abbruch;
else
  return 0;
#else
  return 0;
#endif
}

#endif /* __MPH_problemheap__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MPH_problemheap.h <==
/* $Date: 1999/02/02 08:16:29 $  $Author: jerry $  $Revision: 1.3 $ */

/**************************************************************************/
/* FILE:             MPH_problemheap.h 					  */
/* Autor:            Karsten Morisse                                      */
/* Erstellt:         02/01/92                                             */
/* Letzte Aenderung: 20/02/92                                             */
/**************************************************************************/

#ifndef __MPH_problemheap__
#define __MPH_problemheap__


/**************************************************************************/
/* Dieses File enthaelt die Deklarationen des Modules MPH_problemheap     */
/**************************************************************************/

/**************************************************************************/
/* In MPHTsave werden wichtige Werte f"ur ein Task gespeichert, die keine */
/* S-Zeiger sind.                                                         */
/**************************************************************************/
typedef struct
{
  long MUPV_REAL_PROC_DEPTH ;
  //chh_break:
  short abbruch;  // Muss die Task abgebrochen werden?
  unsigned long process;  // Prozess, der die Task bearbeitet - wird im Moment nicht benoetigt
  jmp_buf back;   // long_jmp-Ruecksprungadresse, wenn Task abgebrochen wird - wird im Moment nicht benoetigt
} MPHTsave ;



	/* Zeiger auf Problemheap					  */
	/* ACHTUNG: Wird nur im Fall 'PARALLEL' wirklich benoetigt.	  */
	/*          Aus Kompatibilitaetsgruenden wird sie jedoch in 	  */
	/*	    beiden Faellen deklariert.				  */

#define MPHC_HISTORY_SIZE_DEFAULT 30


extern S_Pointer	MPHV_START;	
extern S_Pointer	MPHV_RUN;   // chh_break: Runheap
extern jmp_buf          MPHV_JumpBreak; // chh_break: Sprungmarke fuer paralleles break



void MPH_delete_subtasks(S_Pointer parallel_env) ;


#ifdef PARALLEL

S_Pointer MPH_build_task(S_Pointer stmt, S_Pointer priv, S_Pointer cnt, S_Pointer res, S_Pointer ret, S_Pointer break_erlaubt);

void MPH_do_task(S_Pointer task, int set_break_erlaubt);
MUPbool MPH_get();
void MPH_get_sleep() ;
void MPH_init();
void MPH_exit();
void MPH_put(S_Pointer task);
void MPH_prepare_stack(S_Pointer priv, long flag);

//chh_break: Variable, die anzeigt, ob Auswertung wg. Break mit longjump verlassen wurde
GLOBAL_DECL(long, MPHV_BREAKED);

#else

S_Pointer MPH_get_random(long);
S_Pointer MPH_get_task();
S_Pointer MPH_build_task(S_Pointer stmt, S_Pointer priv, S_Pointer cnt, S_Pointer res, S_Pointer ret, S_Pointer break_erlaubt);
 
MUPbool MPH_get(long);
#define MPH_get_sleep() MPH_get(1L) 
void MPH_init();
void MPH_exit();
void MPH_put(S_Pointer task);
void MPH_prepare_stack(S_Pointer priv, long flag);
 
long MPH_count_problemheap();
 
#endif /* PARALLEL */

#ifdef DOS_FILENAMES
  #include "MUP_ext.h"
  #include "MPA_pars.h"
#else
  #include "MUP_extern.h"
  #include "MPA_parser.h"
#endif

// chh_break: Funktion, die abtestet, ob die aktuelle Task abgebrochen werden soll
//            Springt zurueck, wenn ja
inline void MPH_check_actual_task()
{
#ifdef PARALLEL
if ((GLOBAL_READ(MUPV_actual_task_element)) && !(GLOBAL_READ(MUPV_break_impossible)) )
  if ((MMMZ( MMMP(MMMP(&GLOBAL_READ(MUPV_actual_task_element),0L,MMMread), 7L, MMMread) , MPHTsave, MMMread))->abbruch)
  {
    GLOBAL_WRITE(MPHV_BREAKED,1);
    //chh_tmp
    //printf("Prozess %ld bricht Task ab und springt zurueck!\n",GLOBAL_READ(MMMVson));
    longjmp(MPHV_JumpBreak, 1) ;
  }
#endif
}

// chh_break: Funktion, die testet, ob Task als abzubrechen markiert ist.
inline int MPH_check_breaked()
{
#ifdef PARALLEL
if (GLOBAL_READ(MUPV_actual_task_element))
  return (MMMZ( MMMP(MMMP(&GLOBAL_READ(MUPV_actual_task_element),0L,MMMread), 7L, MMMread) , MPHTsave, MMMread))->abbruch;
else
  return 0;
#else
  return 0;
#endif
}

#endif /* __MPH_problemheap__ */
